function [U,iter,res] = Richardson(A,RHS,P,maxit,toler)
% Jacobi iteration for AU = RHS
% P: preconditioner
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

N = length(RHS); % problem size

normRHS = norm(RHS,2);

% initialise
U = zeros(N,1);

% for residual visualisation
residuals = NaN*zeros(maxit,1);

for iter=1:maxit
 U = U - P*(A*U-RHS);
 
 res = norm(A*U-RHS,2)/normRHS;
 
 residuals(iter) = res;
 
 if res<=toler
   break;
 end
end

if iter==maxit
  warning('Richardson: maximal number of iterations reached')
end

if 0
  figure(2001);
  plot([1:maxit]',residuals,'.');
  title('Decay of relative residual for Richardson iteration')
end