% script file splitting.m
% compare different splitting methods
% as a system use minimal surface programm
% implementation of preconditioner is 
% not in an optimal way!!
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

n = 40; % triangulation resolution parameter
[A,RHS,Nodes,TRI] = min_surface_data(n);

maxit = 1000;
toler = 1e-5;

N = length(RHS);


% precompute the unit circle in complex plane
% for spectrum analyse
phi = linspace(0,2*pi,500);
xx = cos(phi);
yy = sin(phi);


% preconditioned Richardson
% (A): no preconditioning: P=identity
P = speye(N,N);
[U,iter,res]=Richardson(A,RHS,P,maxit,toler);
disp(['Iterations for Richardson: ',num2str(iter)])
M = speye(N,N)-P*A;
E = eig(full(M));
figure(2);
plot(real(E),imag(E),'.',xx,yy,'r');
title('Spectrum: Richardson');
axis equal; grid on;

% (B): Jacobi: P = inv(diag(A))
% in this case 1 on the diagonal=> equal to Richardson without preconditioning
d = diag(A);
P = spdiags(1./d,0,N,N);
[U,iter,res]=Richardson(A,RHS,P,maxit,toler);
disp(['Iterations for Jacobi: ',num2str(iter)])
M = speye(N,N)-P*A;
E = eig(full(M));
figure(3);
plot(real(E),imag(E),'.',xx,yy,'r');
title('Spectrum: Jacobi');
axis equal; grid on;

% (C): Gauss-Seidel:
B = tril(A);
P = inv(B); % voll besetzt!!
[U,iter,res]=Richardson(A,RHS,P,maxit,toler);
disp(['Iterations for Gauss Seidel: ',num2str(iter)])
M = speye(N,N)-P*A;
E = eig(full(M));
figure(4);
plot(real(E),imag(E),'.',xx,yy,'r');
title('Spectrum: Gauss-Seidel');
axis equal; grid on;

% (D): JOR:
w = 0.1;
d = 1/w*diag(A);
P = spdiags(1./d,0,N,N);
[U,iter,res]=Richardson(A,RHS,P,maxit,toler);
disp(['Iterations for JOR: ',num2str(iter)])
M = speye(N,N)-P*A;
E = eig(full(M));
figure(5);
plot(real(E),imag(E),'.',xx,yy,'r');
title('Spectrum: JOR');
axis equal; grid on;


% (E): SOR:
d = 1/w*diag(A);
B = tril(A,-1) + spdiags(d,0,N,N);
P = inv(B);
[U,iter,res]=Richardson(A,RHS,P,maxit,toler);
disp(['Iterations for SOR: ',num2str(iter)])
M = speye(N,N)-P*A;
E = eig(full(M));
figure(6);
plot(real(E),imag(E),'.',xx,yy,'r');
title('Spectrum: SOR');
axis equal; grid on;
